@@ -17,7 +17,12 @@ from botocore.hooks import first_non_none_response
 from aiobotocore.httpchecksum import handle_checksum_body
 from aiobotocore.httpsession import AIOHTTPSession
 from aiobotocore.parsers import AioResponseParserFactory
-from aiobotocore.response import StreamingBody
+from aiobotocore.response import HttpxStreamingBody, StreamingBody
+
+try:
+    import httpx
+except ImportError:
+    httpx = None
 
 DEFAULT_HTTP_SESSION_CLS = AIOHTTPSession
 
@@ -50,8 +55,11 @@ async def convert_to_response_dict(http_response, operation_model):
     elif operation_model.has_event_stream_output:
         response_dict['body'] = http_response.raw
     elif operation_model.has_streaming_output:
-        length = response_dict['headers'].get('content-length')
-        response_dict['body'] = StreamingBody(http_response.raw, length)
+        if httpx and isinstance(http_response.raw, httpx.Response):
+            response_dict['body'] = HttpxStreamingBody(http_response.raw)
+        else:
+            length = response_dict['headers'].get('content-length')
+            response_dict['body'] = StreamingBody(http_response.raw, length)
     else:
         response_dict['body'] = await http_response.content
     return response_dict
@@ -217,7 +225,7 @@ class AioEndpoint(Endpoint):
         )
         history_recorder.record('HTTP_RESPONSE', http_response_record_dict)
 
-        protocol = operation_model.metadata['protocol']
+        protocol = operation_model.service_model.resolved_protocol
         customized_response_dict = {}
         await self._event_emitter.emit(
             f"before-parse.{service_id}.{operation_model.name}",
