@@ -3,7 +3,7 @@ import contextlib
 import io
 import os
 import socket
-from typing import Dict, Optional
+from typing import Optional
 
 import aiohttp  # lgtm [py/import-and-import-from]
 from aiohttp import (
@@ -40,6 +40,7 @@ from botocore.httpsession import (
 from multidict import CIMultiDict
 
 import aiobotocore.awsrequest
+import aiobotocore.config
 from aiobotocore._endpoint_helpers import _IOBaseWrapper, _text
 
 
@@ -47,7 +48,7 @@ class AIOHTTPSession:
     def __init__(
         self,
         verify: bool = True,
-        proxies: Dict[str, str] = None,  # {scheme: url}
+        proxies: dict[str, str] = None,  # {scheme: url}
         timeout: float = None,
         max_pool_connections: int = MAX_POOL_CONNECTIONS,
         socket_options=None,
@@ -59,7 +60,7 @@ class AIOHTTPSession:
 
         # TODO: handle socket_options
         # keep track of sessions by proxy url (if any)
-        self._sessions: Dict[Optional[str], aiohttp.ClientSession] = {}
+        self._sessions: dict[Optional[str], aiohttp.ClientSession] = {}
         self._verify = verify
         self._proxy_config = ProxyConfiguration(
             proxies=proxies, proxies_settings=proxies_config
@@ -83,10 +84,9 @@ class AIOHTTPSession:
         self._timeout = timeout
         self._connector_args = connector_args
         if self._connector_args is None:
-            # AWS has a 20 second idle timeout:
-            #   https://web.archive.org/web/20150926192339/https://forums.aws.amazon.com/message.jspa?messageID=215367
-            # aiohttp default timeout is 30s so set something reasonable here
-            self._connector_args = dict(keepalive_timeout=12)
+            self._connector_args = dict(
+                keepalive_timeout=aiobotocore.config.DEFAULT_KEEPALIVE_TIMEOUT
+            )
 
         self._max_pool_connections = max_pool_connections
         self._socket_options = socket_options
@@ -229,8 +229,17 @@ class AIOHTTPSession:
                 proxy_headers=proxy_headers,
             )
 
+            # botocore converts keys to str, so make sure that they are in
+            # the expected case. See detailed discussion here:
+            # https://github.com/aio-libs/aiobotocore/pull/116
+            # aiohttp's CIMultiDict camel cases the headers :(
+            headers = {
+                k.decode('utf-8').lower(): v.decode('utf-8')
+                for k, v in response.raw_headers
+            }
+
             http_response = aiobotocore.awsrequest.AioAWSResponse(
-                str(response.url), response.status, response.headers, response
+                str(response.url), response.status, headers, response
             )
 
             if not request.stream_output:
